.. currentmodule:: pdcast

.. _decimal_types:

Decimal
=======

Generic
-------

.. _decimal_type:

.. autoclass:: DecimalType

Python
------

.. _python_decimal_type:

.. autoclass:: PythonDecimalType
